==> magic3_2.16.3_src.tar.gz: magic3/widgets/admin_main/include/container/test/admin_mainTest_configWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2015 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id$
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
require_once($gEnvManager->getLibPath()				. '/GUMP-1.3/gump.class.php' );

class admin_mainTest_configWidgetContainer extends admin_mainBaseWidgetContainer
{
	private $db;	// DB接続オブジェクト
	const SAMPLE_DIR = 'sample';				// サンプルSQLディレクトリ名
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DB接続オブジェクト作成
		$this->db = new admin_mainDb();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'test/test_config.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		//$this->setUserErrorMsg('エラーメッセージテスト1231312312312313321312321313213131312');
		$this->setAppErrorMsg('エラーメッセージテスト1231312312312313321312321313213131312');
		
		// 入力値取得
		$this->getInputField($act,	'act');
		$this->getInputField($name,	'name');
		$this->getInputField($staticName,	'static_name', 'none');			// 出力のみ
		
		if ($act == 'update'){				// 送信確認

			
			// バリデーションテスト
			$data = array(
			    'street' => 'aasadfa'
			);

			$validated = GUMP::is_valid($data, array(
			    'street' => 'required|street_address'
			));

			if($validated === true) {
			    echo "Valid Street Address!";
			} else {
			    print_r($validated);
			}
		} else {
		}
		$staticName = '固定で出力';			// 出力のみテキスト
		
		// 画面にデータ埋め込み
		$this->putInputField();
	}
}
?>

==> magic3_3.0.0_src.tar.gz: magic3/widgets/admin_main/include/container/test/admin_mainTest_configWidgetContainer.php <==
<?php
/**
 * コンテナクラス
 *
 * PHP versions 5
 *
 * LICENSE: This source file is licensed under the terms of the GNU General Public License.
 *
 * @package    Magic3 Framework
 * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 * @copyright  Copyright 2006-2015 Magic3 Project.
 * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
 * @version    SVN: $Id$
 * @link       http://www.magic3.org
 */
require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');

class admin_mainTest_configWidgetContainer extends admin_mainBaseWidgetContainer
{
	private $db;	// DB接続オブジェクト
	const SAMPLE_DIR = 'sample';				// サンプルSQLディレクトリ名
	
	/**
	 * コンストラクタ
	 */
	function __construct()
	{
		// 親クラスを呼び出す
		parent::__construct();
		
		// DB接続オブジェクト作成
		$this->db = new admin_mainDb();
	}
	/**
	 * テンプレートファイルを設定
	 *
	 * _assign()でデータを埋め込むテンプレートファイルのファイル名を返す。
	 * 読み込むディレクトリは、「自ウィジェットディレクトリ/include/template」に固定。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。そのまま_assign()に渡る
	 * @return string 						テンプレートファイル名。テンプレートライブラリを使用しない場合は空文字列「''」を返す。
	 */
	function _setTemplate($request, &$param)
	{	
		return 'test/test_config.tmpl.html';
	}
	/**
	 * テンプレートにデータ埋め込む
	 *
	 * _setTemplate()で指定したテンプレートファイルにデータを埋め込む。
	 *
	 * @param RequestManager $request		HTTPリクエスト処理クラス
	 * @param object         $param			任意使用パラメータ。_setTemplate()と共有。
	 * @param								なし
	 */
	function _assign($request, &$param)
	{
		//$this->setUserErrorMsg('エラーメッセージテスト1231312312312313321312321313213131312');
		$this->setAppErrorMsg('エラーメッセージテスト1231312312312313321312321313213131312');
		
		// 入力値取得
		$this->getInputField($act,	'act');
		$this->getInputField($name,	'name');
		$this->getInputField($staticName,	'static_name', 'none');			// 出力のみ
		
		if ($act == 'update'){				// 送信確認

			
			// バリデーションテスト
			$data = array(
			    'street' => 'aasadfa'
			);

/*			$validated = GUMP::is_valid($data, array(
			    'street' => 'required|street_address'
			));*/

			if($validated === true) {
			    echo "Valid Street Address!";
			} else {
			    print_r($validated);
			}
		} else {
		}
		$staticName = '固定で出力';			// 出力のみテキスト
		
		// 画面にデータ埋め込み
		$this->putInputField();
	}
}
?>
